@@ -27,13 +27,15 @@
 #include <stdio.h>
 #include "celibc.h"
 #include "ce.h"
+#include "externs.h"
 
 extern struct WINDOW *wpopup();
 
 /*
  * Forward declarations
  */
-extern void itoa();
+static void itoa();
+static int buftowin();
 
 /*
  * Attach a buffer to a window. The values of dot and mark come from the buffer
@@ -516,7 +518,7 @@ makelist()
 	return (TRUE);			  /* All done	     */
 }
 
-void
+static void
 itoa(buf, width, num)
 register char   buf[];
 register int    width;
@@ -673,6 +675,7 @@ register BUFFER *bp;
 	bp->b_doto  = 0;
 	bp->b_markp = NULL;		     /* Invalidate "mark"    */
 	bp->b_marko = 0;
+	mlerase();			/* erase any question */
 	return (TRUE);
 }
 
@@ -750,7 +753,7 @@ register BUFFER *bp;
 /*
  * Make buffer BP appear in window WP.
  */
-int
+static int
 buftowin(bp, wp, flags)
 register BUFFER *bp;
 register WINDOW *wp;
