@@ -42,6 +42,8 @@
  * Since the performance of mg under xterm with this same code is 
  * unacceptable for such scrolls, this should work out well.
  */
+
+#include <stdio.h>
 #include "celibc.h"
 #include "ce.h"
 
@@ -52,12 +54,25 @@ extern char	*xdversion;
 #endif
 
 #ifdef X11
+extern void	xsetname();
 #  define NOGOSLING
 #  define SETNAME(s)	if (s && *s) xsetname(s)
 #else
 #  define SETNAME(s)
 #endif
 
+/* XXX - this needs a header file */
+#ifdef X11
+extern int	x_putline();
+#else
+extern void	tttidy();
+extern void	ttinsl();
+extern void	ttdell();
+extern int	panic();
+#endif
+
+extern int	typeahead();
+
 /*
  * You can change these back to the types
  * implied by the name if you get tight for space. If you
@@ -213,6 +228,7 @@ vttidy()
  */
 void
 vtmove(row, col)
+int	row, col;
 {
 	vtrow = row;
 	vtcol = col;
@@ -614,6 +630,7 @@ register VIDEO	*pvp;
  */
 static void
 updateline(row, vvp, pvp)
+int	row;
 VIDEO	*vvp;
 VIDEO	*pvp;
 {
@@ -897,6 +914,7 @@ register VIDEO	*vp;
  */
 static void
 setscores(offs, size)
+int	offs, size;
 {
 	register SCORE	*sp;
 	register int	tempcost;
@@ -987,6 +1005,7 @@ setscores(offs, size)
  */
 static void
 traceback(offs, size, i, j)
+int	offs, size, i, j;
 {
 	register int	itrace;
 	register int	jtrace;
