@@ -26,6 +26,7 @@
 #include <stdio.h>
 #include "celibc.h"
 #include "ce.h"
+#include "externs.h"
 
 /*
  * Forward declarations
@@ -354,7 +355,7 @@ int	f, n;
 	if ((s = mlgetfile("Write file: ", fname, NFILEN)) == ABORT)
 		return (s);
 	if (fname[0] == '\0') {
-		if (curbp->b_fname && curbp->b_fname[0])
+		if (/* curbp->b_fname && */ curbp->b_fname[0])
 			strcpy(fname, curbp->b_fname);
 		else
 			return(FALSE);
@@ -494,6 +495,7 @@ int	f, n;
 int
 insertfile(fname, silent)
 char    fname[];
+int	silent;
 {
 	register int    s;
 
