@@ -35,6 +35,7 @@
  */
 #include "celibc.h"
 #include "ce.h"
+#include "externs.h"
 
 #define	NBLOCK	16			/* Line block chunk size	*/
 
@@ -659,6 +660,7 @@ kdelete()
  */
 int
 kinsert(c)
+int	c;
 {
 	register char	*nbufp;
 
@@ -688,6 +690,7 @@ kinsert(c)
  */
 int
 kremove(n)
+int	n;
 {
 	if (n >= kused)
 		return (-1);
