@@ -31,6 +31,9 @@
 #include	"ce.h"		/* global structures and defines */
 #undef  MAIN
 
+#include "fio.h"
+#include "externs.h"
+
 #ifndef GOOD
 #define GOOD    0
 #endif
@@ -79,13 +82,13 @@ char	*progname;
  */
 static void	edinit();
 
-extern void	usage();
-
 /* external references */
 
 extern int	isofont;
 
-extern void	rmsave();
+#ifdef X11
+extern int	x_preparse_args();
+#endif
 
 /*
  * Declarations local to this file.
@@ -266,10 +269,12 @@ char	**argv;
 {
 	register int 	carg;
 	register BUFFER *bp;
-	int 		ffile = TRUE;
+	int 		ffile;
 	char		bname[NBUFN];
-	int 		n, goline = FALSE, rdonly = FALSE;
+	int 		n, goline, rdonly;
 
+	goline = rdonly = FALSE;
+	ffile = TRUE;
 	bname[0] = '\0';
 	for (carg = 1; carg < argc; ++carg) {
 		/* if it's a switch, process it */
@@ -349,9 +354,29 @@ char	**argv;
 		update();   /* gotoline forces its own update; this saves one */
 }
 
+/*
+ * Handle the --version argument by printing version information and exiting
+ */
+void
+ce_preparse_args(progname, argc, argv)
+char	*progname;
+int	argc;
+char	**argv;
+{
+	register int i;
+
+	for (i = 1; i < argc; i++)
+		if (argv[i][0] == '-' && argv[i][1] == '-' && strcmp(argv[i], "--version") == 0) {
+			fprintf(stderr, "%s %s\n", progname, versionstring());
+			fprintf(stderr, "Copyright (C) 2011 Chester Ramey\n");
+			exit (0);
+		}
+}
+
 /*
  * Driver for ce
  */
+int
 main(argc, argv)
 int     argc;
 char    **argv;
@@ -361,6 +386,7 @@ char    **argv;
 	else
 		progname = argv[0];
 
+	ce_preparse_args(progname, argc, argv);
 #ifdef X11
 	x_preparse_args(argc, argv);
 #endif
@@ -444,11 +470,11 @@ int	n, c;
 			status = inspound(n, c);
 		else
 			status = linsert(n, c);
-		if (c == '}' || c == ')' || c == ']')
+		if (c == '}' || c == ')' || c == ']' || c == '\'' || c == '"')
 			balance(c);
 	} else if (curbp->b_mode & MDPMATCH) {
 		status = linsert(n, c);
-		if (c == '}' || c == ')' || c == ']')
+		if (c == '}' || c == ')' || c == ']' || c == '\'' || c == '"')
 			balance(c);
 	} else
 		status = linsert(n, c);
