@@ -24,7 +24,9 @@
  */
 
 #include <stdio.h>
+#include "celibc.h"
 #include "ce.h"
+#include "externs.h"
 
 extern int	explarg;
 extern int	kused;
@@ -32,6 +34,9 @@ extern int	followlinks;
 
 int     tabstop;			/* Tab size (0: use real tabs)  */
 
+static int	adjustmode();
+static int	chmode();
+
 /*
  * Update all the mode lines for all the windows
  */
@@ -811,7 +816,7 @@ int	f,n;
 /*
  * Change the editor mode status.
  */
-int
+static int
 adjustmode(kind, global)
 int	kind;	/* true = set,		false = delete */
 int	global;	/* true = global flag,	false = current buffer flag */
@@ -851,7 +856,7 @@ int	global;	/* true = global flag,	false = current buffer flag */
 	return(chmode(cbuf, kind, global));
 }
 
-int
+static int
 chmode(name, setting, global)
 char	*name;
 int 	setting;
