@@ -29,8 +29,12 @@
  *
  * Some improvements by Chet Ramey; more from mg2a
  */
+
+#include <stdio.h>
+
 #include "celibc.h"
 #include "ce.h"
+#include "externs.h"
 
 #ifndef NULL
 #define NULL 0
@@ -494,6 +498,7 @@ int	dir, flag, success;
 static void
 is_dspl(prompt, flag)
 char	*prompt;
+int	flag;
 {
 	char	npat[NPAT*2];
 
