@@ -20,13 +20,17 @@
  *  version.c -- show current version of ce, as well as the date compiled 
  *		 (created dynamically each time ce is compiled).
  */
+#include <stdio.h>
+
 #ifndef HOSTINFO
 #  define HOSTINFO "unknown"
 #endif
 
-char 	*version = "version 4.6";
-char	*dversion = "ce 4.6";
-char	*xdversion = "xce 4.6";
+extern void mlwrite(const char *, ...);
+
+char 	*version = STRVERSION;
+char	*dversion = CEVERSION;
+char	*xdversion = XCEVERSION;
 
 extern int	versnum;
 extern char	datecompiled[];
