@@ -44,6 +44,7 @@
 #include <stdio.h>
 
 #include "celibc.h"
+#include "externs.h"
 
 extern char	*progname;
 extern int	isofont;
@@ -168,6 +169,8 @@ static int x_scroll();
 static void change_selection();
 static void x_stash_selection();
 
+static int	isisofont();
+
 #define	DEFAULT_FONTNAME "-misc-fixed-medium-r-normal--13-120-75-75-c-80-iso8859-1"
 
 static char *fontname;
@@ -191,8 +194,8 @@ void	x_set_geometry();
 
 TERM    term =
 {
-	NULL,
-	NULL,
+	0,
+	0,
 	x_init,
 	x_open,
 	x_close,
@@ -2174,7 +2177,7 @@ cansusp()
 	return 1;
 }
 
-int
+static int
 isisofont(fn)
 char	*fn;
 {
